package de.frajul.endlessroll.views;

import android.graphics.Typeface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

import de.frajul.endlessroll.R;
import de.frajul.endlessroll.entities.Player;
import de.frajul.endlessroll.entities.shapes.PlayerShape;
import de.frajul.endlessroll.main.GameActivity;
import de.frajul.endlessroll.main.GameLog;
import de.frajul.endlessroll.main.game.Game;
import de.frajul.endlessroll.main.screens.Screen;

/**
 * Created by Julian on 15.07.2016.
 */
public class TaskCompletedMessage implements View.OnClickListener, BountyMessage.ScreenSwitchCaller {

    private GameActivity gameActivity;
    private FrameLayout layout;

    private TextView textView;
    private LinearLayout messagesLayout;

    private List<PlayerShape> unlockedShapes = new ArrayList<>();

    public TaskCompletedMessage(GameActivity gameActivity) {
        this.gameActivity = gameActivity;

        Typeface typeface = gameActivity.getTypeface();
        LayoutInflater inflater = LayoutInflater.from(gameActivity);
        layout = (FrameLayout) inflater.inflate(R.layout.task_completed_message, null);
        layout.setOnClickListener(this);
        layout.setLayoutParams(new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT,
                ViewGroup.LayoutParams.MATCH_PARENT));
        layout.setVisibility(View.GONE);
        textView = (TextView) layout.findViewById(R.id.task_completed_text);
        textView.setTypeface(typeface);
        TextView title = (TextView) layout.findViewById(R.id.task_completed_title);
        title.setTypeface(typeface);
        messagesLayout = (LinearLayout) layout.findViewById(R.id.task_completed_unlock_list);
    }

    public void show(List<PlayerShape> shapes) {
        unlockedShapes.clear();
        unlockedShapes.addAll(shapes);
        showNextShape();
    }

    private void showNextShape() {
        messagesLayout.removeAllViews();
        PlayerShape shape = unlockedShapes.remove(0);

        textView.setText(
                shape.getUnlockTask().toString(gameActivity, gameActivity.getLevelManager()));
        BountyMessage message = createBountyMessage(shape);
        messagesLayout.addView(message.getLayout());

        layout.setVisibility(View.VISIBLE);
    }

    private BountyMessage createBountyMessage(PlayerShape shape) {
        return new BountyMessage(gameActivity, BountyMessage.MessageType.SHAPE_UNLOCKED, null, this,
                shape.getDrawableId());
    }

    private void hide() {
        layout.setVisibility(View.GONE);
        messagesLayout.removeAllViews();
    }

    public FrameLayout getLayout() {
        return layout;
    }

    @Override
    public void onClick(View v) {
        if (unlockedShapes.isEmpty())
            hide();
        else
            showNextShape();
    }


    @Override
    public void switchScreen(Screen.ScreenType screenType) {
        gameActivity.flipToScreen(screenType);
        hide();
    }
}
